.. akhdefo documentation master file, created by
   sphinx-quickstart on Wed Jan 11 16:03:09 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to akhdefo's documentation!
===================================
Contents
--------

.. toctree::

   api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
